@@ -45,7 +45,7 @@ class Resource (Model):
 
     class Meta(Model.Meta):
         serializer_fields = ["@id", "name", "shortdesc", "longdesc", "type", "img", "document",\
-                           "link", "keywords", "conversations", "circle"]
+                           "link", "keywords", "conversations", "circle", "creationDate"]
         auto_author = 'user'
         owner_field = 'user'
         container_path = 'resources/'
